@@ -8,6 +8,8 @@ BIFIE.derivedParameters <- function( BIFIE.method , derived.parameters , type=NU
 	
 	object <- res1 <- BIFIE.method		
 	parnames <- res1$parnames
+	Nimp <- res1$Nimp
+	RR <- res1$RR
 			
 	# extract replicated parameters
 	parsres <- extract.replicated.pars( BIFIE.method = res1 , type=type )
@@ -43,12 +45,17 @@ BIFIE.derivedParameters <- function( BIFIE.method , derived.parameters , type=NU
 	parsrepM <- as.matrix( t( der.pars.rep ) )
 	rdes <- c(0)
 	# compute covariance matrices
-	res0 <- .Call("bifie_waldtest" ,  parsM = parsM , parsrepM = parsrepM , 
-						Cdes , rdes , Ccols - 1 , fayfac=fayfac ,
+	# Function for (ordinary) multiple imputation
+
+if (TRUE){	
+	res0 <- .Call("bifie_waldtest" ,  parsM , parsrepM , 
+						Cdes , rdes , Ccols - 1 , fayfac ,
 						PACKAGE="BIFIEsurvey")
+			}
+#	res0 <- bifie_waldtest(  parsM , parsrepM , 
+#						Cdes , rdes , Ccols - 1 , fayfac )
 	var_w <- res0$var_w
-	var_b <- res0$var_b
-	Nimp <- res1$Nimp
+	var_b <- res0$var_b	
 	# total variance
 	var_tot <- var_w  + ( 1 + 1/Nimp ) * var_b 
 	parmlabel <- names(derived.parameters)
@@ -56,23 +63,43 @@ BIFIE.derivedParameters <- function( BIFIE.method , derived.parameters , type=NU
 	stat <- data.frame( "parmlabel" = parmlabel , "coef"= rowMeans( parsM ) ,
 				"se" = sqrt( diag( var_tot ) ) ) 
 	# pars_fmi[pp] = ( 1.0 + 1/Nimp2) * pars_varBetween[pp] / pow(pars_se[pp] + eps,2.0) ;
-	eps <- 1E-10
-	
+	eps <- 1E-10	
 	stat$t <- stat$coef / stat$se
-	stat$p <- 2* pnorm( - abs( stat$t ) )
+	stat$df <- rubin_calc_df2( B= diag(var_b) , W=diag(var_w) , Nimp , digits=2)
+#	stat$p <- 2* pnorm( - abs( stat$t ) )
+	stat$p <- 2*pt( - abs(stat$t) , df = stat$df )
 	stat$fmi <-  ( 1+1/Nimp) * diag(var_b) / ( stat$se^2 + eps )           
 	stat$VarMI <- diag( var_b )
 	stat$VarRep <- diag( var_w )               
 	rownames(stat) <- NULL         
+
+	if (BIFIE.method$NMI){
+	    Nimp_NMI <- BIFIE.method$Nimp_NMI
+		res0 <- BIFIE_NMI_inference_parameters( parsM , parsrepM , fayfac ,
+				RR , Nimp , Nimp_NMI , comp_cov = FALSE )	
+		stat$coef <- res0$pars
+        stat$se <- res0$pars_se		
+		stat$df <- res0$df
+		stat$t <- res0$pars / res0$pars_se
+		stat$p <- 2*pt( - abs(stat$t) , df = stat$df )
+		stat$fmi <- res0$pars_fmi
+		stat$VarMI <- res0$pars_varBetween1 +	res0$pars_varBetween2
+		stat$fmi_St1 <- res0$pars_fmiB
+		stat$fmi_St2 <- res0$pars_fmiW
+						
+						}
+	
 	s2 <- Sys.time()
 	timediff <- c( s1 , s2 ) # , paste(s2-s1 ) )	
 	res <- list( "stat" = stat , "coef"= rowMeans( parsM ) ,
 				"se" = sqrt( diag( var_tot ) ) ,
 				"vcov" = var_tot , "Nimp" = Nimp , "fayfac" = fayfac ,
 				"N"=res1$N , "RR"=res1$RR , 
+				"NMI" = BIFIE.method$NMI , "Nimp_NMI" = BIFIE.method$Nimp_NMI , 
 				"allformulas" = allformulas , "CALL"=cl ,
 				"timediff" = timediff 	,
 				"derived.parameters" = derived.parameters ,
+				"parsM" = parsM , parsrepM = parsrepM , 
 				"parnames" = names(derived.parameters)
 						)	
 	class(res) <- "BIFIE.derivedParameters"
@@ -84,7 +111,7 @@ BIFIE.derivedParameters <- function( BIFIE.method , derived.parameters , type=NU
 # summary for BIFIE.derivedParameters function
 summary.BIFIE.derivedParameters <- function( object , digits=4 , ... ){
     BIFIE.summary(object)
-	cat("Formulas for Derived Parameters \n")	
+	cat("Formulas for Derived Parameters \n\n")	
 	FF <- length( object$derived.parameters)
 	for (ff in 1:FF){
 		# ff <- 1
